==> cloud-5.7.0.tar.gz: cloud/modules/cloud_service_providers/openstack/src/Form/OpenStackSubnetEditForm.php <==
<?php

namespace Drupal\openstack\Form;

use Drupal\aws_cloud\Form\Ec2\AwsCloudContentForm;
use Drupal\aws_cloud\Service\AwsCloud\AwsCloudOperationsServiceInterface;
use Drupal\aws_cloud\Service\Ec2\Ec2ServiceInterface;
use Drupal\aws_cloud\Traits\AwsCloudFormTrait;
use Drupal\cloud\Plugin\cloud\config\CloudConfigPluginManagerInterface;
use Drupal\cloud\Service\CloudServiceInterface;
use Drupal\cloud\Service\EntityLinkRendererInterface;
use Drupal\cloud\Service\Util\EntityLinkWithNameHtmlGenerator;
use Drupal\cloud\Traits\CloudContentEntityTrait;
use Drupal\Component\Datetime\TimeInterface;
use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\Datetime\DateFormatterInterface;
use Drupal\Core\Entity\EntityRepositoryInterface;
use Drupal\Core\Entity\EntityTypeBundleInfoInterface;
use Drupal\Core\Entity\EntityTypeManager;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Messenger\Messenger;
use Drupal\Core\Plugin\CachedDiscoveryClearerInterface;
use Drupal\Core\Render\Renderer;
use Drupal\Core\Routing\RouteMatchInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\openstack\Entity\OpenStackSubnetInterface;
use Drupal\openstack\Service\OpenStackOperationsServiceInterface;
use Drupal\openstack\Service\OpenStackServiceFactoryInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Form controller for the Subnet entity edit form.
 *
 * @ingroup openstack
 */
class OpenStackSubnetEditForm extends AwsCloudContentForm {

  use AwsCloudFormTrait;
  use CloudContentEntityTrait;

  /**
   * The OpenStack Service Factory.
   *
   * @var \Drupal\openstack\Service\OpenStackServiceFactoryInterface
   */
  protected $openStackServiceFactory;

  /**
   * The OpenStack operations Service.
   *
   * @var \Drupal\openstack\Service\OpenStackOperationsServiceInterface
   */
  protected $openStackOperationsService;

  /**
   * OpenStackSubnetEditForm constructor.
   *
   * @param \Drupal\aws_cloud\Service\AwsCloud\AwsCloudOperationsServiceInterface $aws_cloud_operations_service
   *   The AWS Cloud Operations service.
   * @param \Drupal\openstack\Service\OpenStackServiceFactoryInterface $openstack_service_factory
   *   Object for interfacing with OpenStack Service.
   * @param \Drupal\aws_cloud\Service\Ec2\Ec2ServiceInterface $ec2_service
   *   The AWS Cloud or OpenStack EC2 Service.
   * @param \Drupal\Core\Entity\EntityRepositoryInterface $entity_repository
   *   The entity repository service.
   * @param \Drupal\Core\Entity\EntityTypeBundleInfoInterface $entity_type_bundle_info
   *   The entity type bundle service.
   * @param \Drupal\Component\Datetime\TimeInterface $time
   *   The time service.
   * @param \Drupal\Core\Messenger\Messenger $messenger
   *   The Messenger Service.
   * @param \Drupal\cloud\Service\EntityLinkRendererInterface $entity_link_renderer
   *   The entity link render service.
   * @param \Drupal\Core\Entity\EntityTypeManager $entity_type_manager
   *   The Entity Type Manager.
   * @param \Drupal\Core\Cache\CacheBackendInterface $cacheRender
   *   A cache backend interface instance.
   * @param \Drupal\Core\Plugin\CachedDiscoveryClearerInterface $plugin_cache_clearer
   *   A plugin cache clear instance.
   * @param \Drupal\cloud\Plugin\cloud\config\CloudConfigPluginManagerInterface $cloud_config_plugin_manager
   *   The cloud service provider plugin manager (CloudConfigPluginManager).
   * @param \Drupal\Core\Session\AccountInterface $current_user
   *   The current user.
   * @param \Drupal\Core\Routing\RouteMatchInterface $route_match
   *   The route match.
   * @param \Drupal\Core\Datetime\DateFormatterInterface $date_formatter
   *   The date formatter.
   * @param \Drupal\Core\Render\Renderer $renderer
   *   The general renderer.
   * @param \Drupal\cloud\Service\CloudServiceInterface $cloud_service
   *   The Cloud service.
   * @param \Drupal\openstack\Service\OpenStackOperationsServiceInterface $openstack_operations_service
   *   The OpenStack Operations service.
   */
  public function __construct(
    AwsCloudOperationsServiceInterface $aws_cloud_operations_service,
    OpenStackServiceFactoryInterface $openstack_service_factory,
    Ec2ServiceInterface $ec2_service,
    EntityRepositoryInterface $entity_repository,
    EntityTypeBundleInfoInterface $entity_type_bundle_info,
    TimeInterface $time,
    Messenger $messenger,
    EntityLinkRendererInterface $entity_link_renderer,
    EntityTypeManager $entity_type_manager,
    CacheBackendInterface $cacheRender,
    CachedDiscoveryClearerInterface $plugin_cache_clearer,
    CloudConfigPluginManagerInterface $cloud_config_plugin_manager,
    AccountInterface $current_user,
    RouteMatchInterface $route_match,
    DateFormatterInterface $date_formatter,
    Renderer $renderer,
    CloudServiceInterface $cloud_service,
    OpenStackOperationsServiceInterface $openstack_operations_service) {

    parent::__construct(
      $ec2_service,
      $entity_repository,
      $entity_type_bundle_info,
      $time,
      $messenger,
      $entity_link_renderer,
      $entity_type_manager,
      $cacheRender,
      $plugin_cache_clearer,
      $cloud_config_plugin_manager,
      $current_user,
      $route_match,
      $date_formatter,
      $renderer,
      $cloud_service
    );

    $this->openStackServiceFactory = $openstack_service_factory;
    $this->openStackOperationsService = $openstack_operations_service;
  }

  /**
   * Dependency Injection.
   *
   * @param \Symfony\Component\DependencyInjection\ContainerInterface $container
   *   Instance of ContainerInterface.
   *
   * @return OpenStackSubnetEditForm
   *   return created object.
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('aws_cloud.operations'),
      $container->get('openstack.factory'),
      $container->get('openstack.ec2'),
      $container->get('entity.repository'),
      $container->get('entity_type.bundle.info'),
      $container->get('datetime.time'),
      $container->get('messenger'),
      $container->get('entity.link_renderer'),
      $container->get('entity_type.manager'),
      $container->get('cache.render'),
      $container->get('plugin.cache_clearer'),
      $container->get('plugin.manager.cloud_config_plugin'),
      $container->get('current_user'),
      $container->get('current_route_match'),
      $container->get('date.formatter'),
      $container->get('renderer'),
      $container->get('cloud'),
      $container->get('openstack.operations')
    );
  }

  /**
   * Overrides Drupal\Core\Entity\EntityFormController::buildForm().
   *
   * @param array $form
   *   Array of form object.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current form state.
   * @param string $cloud_context
   *   A cloud_context string value from URL "path".
   *
   * @return array
   *   Array of form object.
   */
  public function buildForm(array $form, FormStateInterface $form_state, $cloud_context = ''): array {

    // Switch OpenStack EC2 or REST service based on $cloud_context.
    $this->ec2Service = $this->openStackServiceFactory->get($cloud_context);

    $form = parent::buildForm($form, $form_state, $cloud_context);

    /** @var \Drupal\openstack\Entity\OpenStackSubnetInterface $entity */
    $entity = $this->entity;
    if (!$this->updateEntityBuildForm($entity)) {
      return $this->redirectUrl;
    }

    $weight = -50;

    $form['subnet'] = [
      '#type' => 'details',
      '#title' => $this->t('@title', ['@title' => $entity->getEntityType()->getSingularLabel()]),
      '#open' => TRUE,
      '#weight' => $weight++,
    ];

    $form['subnet']['name'] = [
      '#type'          => 'textfield',
      '#title'         => $this->t('Name'),
      '#maxlength'     => 255,
      '#size'          => 60,
      '#default_value' => $entity->label(),
      '#weight'        => -5,
      '#required'      => TRUE,
    ];

    $form['subnet']['network_id'] = $this->entityLinkRenderer->renderFormElements(
      $entity->getNetworkId(),
      'openstack_network',
      'network_id',
      ['#title' => $this->getItemTitle($this->t('Network'))],
      '',
      EntityLinkWithNameHtmlGenerator::class
    );

    $form['subnet']['cidr'] = [
      '#type'          => 'item',
      '#title'         => $this->getItemTitle($this->t('CIDR')),
      '#markup'        => $entity->getCidr(),
    ];

    $form['subnet']['gateway_ip'] = [
      '#type'          => 'textfield',
      '#title'         => $this->t('Gateway IP'),
      '#description'   => $this->t('IP address of Gateway (e.g. 192.168.0.254).'),
      '#default_value' => $entity->getGatewayIp(),
      '#required'      => FALSE,
      '#states'        => [
        'invisible' => [
          [
            ':input[name=disable_gateway]' => ['checked' => TRUE],
          ],
        ],
      ],
    ];

    $form['subnet']['disable_gateway'] = [
      '#type'          => 'checkbox',
      '#title'         => $this->t('Disable Gateway'),
      '#default_value' => empty($entity->getGatewayIp()),
      '#required'      => FALSE,
    ];

    $form['subnet']['enable_dhcp'] = [
      '#type'          => 'checkbox',
      '#title'         => $this->t('Enable DHCP'),
      '#default_value' => $entity->getEnableDhcp(),
      '#required'      => FALSE,
    ];

    $items = [];
    foreach ($entity->getAllocationPools() ?: [] as $pool) {
      $items[] = str_replace(' - ', ',', $pool['value']);
    }
    $form['subnet']['allocation_pools'] = [
      '#type'          => 'textarea',
      '#title'         => $this->t('Allocation pools'),
      '#description'   => $this->t('IP address allocation pools. Each entry is: start_ip_address,end_ip_address (e.g., 192.168.1.100,192.168.1.120) and one entry per line.'),
      '#default_value' => implode("\n", $items),
      '#required'      => FALSE,
    ];

    $items = [];
    foreach ($entity->getDnsNameServers() ?: [] as $server) {
      $items[] = $server['value'];
    }
    $form['subnet']['dns_name_servers'] = [
      '#type'          => 'textarea',
      '#title'         => $this->t('DNS name servers'),
      '#description'   => $this->t('IP address list of DNS name servers for this subnet. One entry per line.'),
      '#default_value' => implode("\n", $items),
      '#required'      => FALSE,
    ];

    $items = [];
    foreach ($entity->getHostRoutes() ?: [] as $route) {
      preg_match('/nexthop: ([0-9\.]+), destination: ([0-9\.\/]+)/', $route['value'], $matches);
      if (empty($matches) || count($matches) !== 3) {
        continue;
      }

      $items[] = sprintf('%s, %s', $matches[2], $matches[1]);
    }
    $form['subnet']['host_routes'] = [
      '#type'          => 'textarea',
      '#title'         => $this->t('Host Routes'),
      '#description'   => $this->t('Additional routes announced to the hosts. Each entry is: destination_cidr,nexthop (e.g., 192.168.200.0/24,10.56.1.254) and one entry per line.'),
      '#default_value' => implode("\n", $items),
      '#required'      => FALSE,
    ];

    $this->addOthersFieldset($form, $weight++, $cloud_context);

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state): ?OpenStackSubnetInterface {
    /** @var \Drupal\openstack\Entity\OpenStackSubnetInterface $entity */
    $entity = parent::validateForm($form, $form_state);
    if (empty($form_state->getValue('disable_gateway')) && empty($entity->getGatewayIp())) {
      $form_state->setErrorByName('gateway_ip', $this->t('Specify IP address of gateway or check "Disable Gateway" checkbox.'));
    }

    return $entity;
  }

  /**
   * Submit handler.
   *
   * @param array $form
   *   Array of form object.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current form state.
   */
  public function save(array $form, FormStateInterface $form_state): void {
    $this->openStackOperationsService->editOpenStackSubnet($this->entity, $form, $form_state);
  }

}

==> cloud-6.0.0-rc2.tar.gz: cloud/modules/cloud_service_providers/openstack/src/Form/OpenStackSubnetEditForm.php <==
<?php

namespace Drupal\openstack\Form;

use Drupal\aws_cloud\Form\Ec2\AwsCloudContentForm;
use Drupal\aws_cloud\Service\AwsCloud\AwsCloudOperationsServiceInterface;
use Drupal\aws_cloud\Service\Ec2\Ec2ServiceInterface;
use Drupal\aws_cloud\Traits\AwsCloudFormTrait;
use Drupal\cloud\Plugin\cloud\config\CloudConfigPluginManagerInterface;
use Drupal\cloud\Service\CloudServiceInterface;
use Drupal\cloud\Service\EntityLinkRendererInterface;
use Drupal\cloud\Service\Util\EntityLinkWithNameHtmlGenerator;
use Drupal\cloud\Traits\CloudContentEntityTrait;
use Drupal\Component\Datetime\TimeInterface;
use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\Datetime\DateFormatterInterface;
use Drupal\Core\Entity\EntityRepositoryInterface;
use Drupal\Core\Entity\EntityTypeBundleInfoInterface;
use Drupal\Core\Entity\EntityTypeManager;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Messenger\Messenger;
use Drupal\Core\Plugin\CachedDiscoveryClearerInterface;
use Drupal\Core\Render\Renderer;
use Drupal\Core\Routing\RouteMatchInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\openstack\Service\OpenStackOperationsServiceInterface;
use Drupal\openstack\Service\OpenStackServiceFactoryInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Form controller for the Subnet entity edit form.
 *
 * @ingroup openstack
 */
class OpenStackSubnetEditForm extends AwsCloudContentForm {

  use AwsCloudFormTrait;
  use CloudContentEntityTrait;

  /**
   * The OpenStack Service Factory.
   *
   * @var \Drupal\openstack\Service\OpenStackServiceFactoryInterface
   */
  protected $openStackServiceFactory;

  /**
   * The OpenStack operations Service.
   *
   * @var \Drupal\openstack\Service\OpenStackOperationsServiceInterface
   */
  protected $openStackOperationsService;

  /**
   * OpenStackSubnetEditForm constructor.
   *
   * @param \Drupal\aws_cloud\Service\AwsCloud\AwsCloudOperationsServiceInterface $aws_cloud_operations_service
   *   The AWS Cloud Operations service.
   * @param \Drupal\openstack\Service\OpenStackServiceFactoryInterface $openstack_service_factory
   *   Object for interfacing with OpenStack Service.
   * @param \Drupal\aws_cloud\Service\Ec2\Ec2ServiceInterface $ec2_service
   *   The AWS Cloud or OpenStack EC2 Service.
   * @param \Drupal\Core\Entity\EntityRepositoryInterface $entity_repository
   *   The entity repository service.
   * @param \Drupal\Core\Entity\EntityTypeBundleInfoInterface $entity_type_bundle_info
   *   The entity type bundle service.
   * @param \Drupal\Component\Datetime\TimeInterface $time
   *   The time service.
   * @param \Drupal\Core\Messenger\Messenger $messenger
   *   The Messenger Service.
   * @param \Drupal\cloud\Service\EntityLinkRendererInterface $entity_link_renderer
   *   The entity link render service.
   * @param \Drupal\Core\Entity\EntityTypeManager $entity_type_manager
   *   The Entity Type Manager.
   * @param \Drupal\Core\Cache\CacheBackendInterface $cacheRender
   *   A cache backend interface instance.
   * @param \Drupal\Core\Plugin\CachedDiscoveryClearerInterface $plugin_cache_clearer
   *   A plugin cache clear instance.
   * @param \Drupal\cloud\Plugin\cloud\config\CloudConfigPluginManagerInterface $cloud_config_plugin_manager
   *   The cloud service provider plugin manager (CloudConfigPluginManager).
   * @param \Drupal\Core\Session\AccountInterface $current_user
   *   The current user.
   * @param \Drupal\Core\Routing\RouteMatchInterface $route_match
   *   The route match.
   * @param \Drupal\Core\Datetime\DateFormatterInterface $date_formatter
   *   The date formatter.
   * @param \Drupal\Core\Render\Renderer $renderer
   *   The general renderer.
   * @param \Drupal\cloud\Service\CloudServiceInterface $cloud_service
   *   The Cloud service.
   * @param \Drupal\openstack\Service\OpenStackOperationsServiceInterface $openstack_operations_service
   *   The OpenStack Operations service.
   */
  public function __construct(
    AwsCloudOperationsServiceInterface $aws_cloud_operations_service,
    OpenStackServiceFactoryInterface $openstack_service_factory,
    Ec2ServiceInterface $ec2_service,
    EntityRepositoryInterface $entity_repository,
    EntityTypeBundleInfoInterface $entity_type_bundle_info,
    TimeInterface $time,
    Messenger $messenger,
    EntityLinkRendererInterface $entity_link_renderer,
    EntityTypeManager $entity_type_manager,
    CacheBackendInterface $cacheRender,
    CachedDiscoveryClearerInterface $plugin_cache_clearer,
    CloudConfigPluginManagerInterface $cloud_config_plugin_manager,
    AccountInterface $current_user,
    RouteMatchInterface $route_match,
    DateFormatterInterface $date_formatter,
    Renderer $renderer,
    CloudServiceInterface $cloud_service,
    OpenStackOperationsServiceInterface $openstack_operations_service) {

    parent::__construct(
      $ec2_service,
      $entity_repository,
      $entity_type_bundle_info,
      $time,
      $messenger,
      $entity_link_renderer,
      $entity_type_manager,
      $cacheRender,
      $plugin_cache_clearer,
      $cloud_config_plugin_manager,
      $current_user,
      $route_match,
      $date_formatter,
      $renderer,
      $cloud_service
    );

    $this->openStackServiceFactory = $openstack_service_factory;
    $this->openStackOperationsService = $openstack_operations_service;
  }

  /**
   * Dependency Injection.
   *
   * @param \Symfony\Component\DependencyInjection\ContainerInterface $container
   *   Instance of ContainerInterface.
   *
   * @return OpenStackSubnetEditForm
   *   return created object.
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('aws_cloud.operations'),
      $container->get('openstack.factory'),
      $container->get('openstack.ec2'),
      $container->get('entity.repository'),
      $container->get('entity_type.bundle.info'),
      $container->get('datetime.time'),
      $container->get('messenger'),
      $container->get('entity.link_renderer'),
      $container->get('entity_type.manager'),
      $container->get('cache.render'),
      $container->get('plugin.cache_clearer'),
      $container->get('plugin.manager.cloud_config_plugin'),
      $container->get('current_user'),
      $container->get('current_route_match'),
      $container->get('date.formatter'),
      $container->get('renderer'),
      $container->get('cloud'),
      $container->get('openstack.operations')
    );
  }

  /**
   * Overrides Drupal\Core\Entity\EntityFormController::buildForm().
   *
   * @param array $form
   *   Array of form object.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current form state.
   * @param string $cloud_context
   *   A cloud_context string value from URL "path".
   *
   * @return array
   *   Array of form object.
   */
  public function buildForm(array $form, FormStateInterface $form_state, $cloud_context = ''): array {

    // Switch OpenStack EC2 or REST service based on $cloud_context.
    $this->ec2Service = $this->openStackServiceFactory->get($cloud_context);

    $form = parent::buildForm($form, $form_state, $cloud_context);

    $entity = $this->entity;
    if (!$this->updateEntityBuildForm($entity)) {
      return $this->redirectUrl;
    }

    $weight = -50;

    $form['subnet'] = [
      '#type' => 'details',
      '#title' => $this->t('@title', ['@title' => $entity->getEntityType()->getSingularLabel()]),
      '#open' => TRUE,
      '#weight' => $weight++,
    ];

    $form['subnet']['name'] = [
      '#type'          => 'textfield',
      '#title'         => $this->t('Name'),
      '#maxlength'     => 255,
      '#size'          => 60,
      '#default_value' => $entity->label(),
      '#weight'        => -5,
      '#required'      => TRUE,
    ];

    $form['subnet']['network_id'] = $this->entityLinkRenderer->renderFormElements(
      $entity->getNetworkId(),
      'openstack_network',
      'network_id',
      ['#title' => $this->getItemTitle($this->t('Network'))],
      '',
      EntityLinkWithNameHtmlGenerator::class
    );

    $form['subnet']['cidr'] = [
      '#type'          => 'item',
      '#title'         => $this->getItemTitle($this->t('CIDR')),
      '#markup'        => $entity->getCidr(),
    ];

    $form['subnet']['gateway_ip'] = [
      '#type'          => 'textfield',
      '#title'         => $this->t('Gateway IP'),
      '#description'   => $this->t('IP address of Gateway (e.g. 192.168.0.254).'),
      '#default_value' => $entity->getGatewayIp(),
      '#required'      => FALSE,
      '#states'        => [
        'invisible' => [
          [
            ':input[name=disable_gateway]' => ['checked' => TRUE],
          ],
        ],
      ],
    ];

    $form['subnet']['disable_gateway'] = [
      '#type'          => 'checkbox',
      '#title'         => $this->t('Disable Gateway'),
      '#default_value' => empty($entity->getGatewayIp()),
      '#required'      => FALSE,
    ];

    $form['subnet']['enable_dhcp'] = [
      '#type'          => 'checkbox',
      '#title'         => $this->t('Enable DHCP'),
      '#default_value' => $entity->getEnableDhcp(),
      '#required'      => FALSE,
    ];

    $items = [];
    foreach ($entity->getAllocationPools() ?: [] as $pool) {
      $items[] = str_replace(' - ', ',', $pool['value']);
    }
    $form['subnet']['allocation_pools'] = [
      '#type'          => 'textarea',
      '#title'         => $this->t('Allocation pools'),
      '#description'   => $this->t('IP address allocation pools. Each entry is: start_ip_address,end_ip_address (e.g., 192.168.1.100,192.168.1.120) and one entry per line.'),
      '#default_value' => implode("\n", $items),
      '#required'      => FALSE,
    ];

    $items = [];
    foreach ($entity->getDnsNameServers() ?: [] as $server) {
      $items[] = $server['value'];
    }
    $form['subnet']['dns_name_servers'] = [
      '#type'          => 'textarea',
      '#title'         => $this->t('DNS name servers'),
      '#description'   => $this->t('IP address list of DNS name servers for this subnet. One entry per line.'),
      '#default_value' => implode("\n", $items),
      '#required'      => FALSE,
    ];

    $items = [];
    foreach ($entity->getHostRoutes() ?: [] as $route) {
      preg_match('/nexthop: ([0-9\.]+), destination: ([0-9\.\/]+)/', $route['value'], $matches);
      if (empty($matches) || count($matches) !== 3) {
        continue;
      }

      $items[] = sprintf('%s,%s', $matches[2], $matches[1]);
    }
    $form['subnet']['host_routes'] = [
      '#type'          => 'textarea',
      '#title'         => $this->t('Host Routes'),
      '#description'   => $this->t('Additional routes announced to the hosts. Each entry is: destination_cidr,nexthop (e.g., 192.168.200.0/24,10.56.1.254) and one entry per line.'),
      '#default_value' => implode("\n", $items),
      '#required'      => FALSE,
    ];

    $this->addOthersFieldset($form, $weight++, $cloud_context);

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    $entity = parent::validateForm($form, $form_state);
    if (empty($form_state->getValue('disable_gateway')) && empty($entity->getGatewayIp())) {
      $form_state->setErrorByName('gateway_ip', $this->t('Specify IP address of gateway or check "Disable Gateway" checkbox.'));
    }

    return $entity;
  }

  /**
   * Submit handler.
   *
   * @param array $form
   *   Array of form object.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current form state.
   */
  public function save(array $form, FormStateInterface $form_state): void {
    $this->openStackOperationsService->editOpenStackSubnet($this->entity, $form, $form_state);
  }

}
